/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.games.model;

import com.google.api.client.json.GenericJson;

/**
 * This is a JSON template for an achievement definition object.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Google Play Game Services API. For a detailed
 * explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class AchievementDefinition extends GenericJson {

  /**
   * The type of the achievement. Possible values are:   - "STANDARD" - Achievement is either locked
   * or unlocked.  - "INCREMENTAL" - Achievement is incremental.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String achievementType;

  /**
   * The description of the achievement.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String description;

  /**
   * The total steps for an incremental achievement as a string.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String formattedTotalSteps;

  /**
   * The ID of the achievement.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * The initial state of the achievement. Possible values are:   - "HIDDEN" - Achievement is
   * hidden.  - "REVEALED" - Achievement is revealed.  - "UNLOCKED" - Achievement is unlocked.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String initialState;

  /**
   * Indicates whether the revealed icon image being returned is a default image, or is provided by
   * the game.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean isRevealedIconUrlDefault;

  /**
   * Indicates whether the unlocked icon image being returned is a default image, or is game-
   * provided.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean isUnlockedIconUrlDefault;

  /**
   * Uniquely identifies the type of this resource. Value is always the fixed string
   * games#achievementDefinition.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The name of the achievement.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String name;

  /**
   * The image URL for the revealed achievement icon.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String revealedIconUrl;

  /**
   * The total steps for an incremental achievement.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Integer totalSteps;

  /**
   * The image URL for the unlocked achievement icon.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String unlockedIconUrl;

  /**
   * The type of the achievement. Possible values are:   - "STANDARD" - Achievement is either locked
   * or unlocked.  - "INCREMENTAL" - Achievement is incremental.
   * The value returned may be {@code null}.
   */
  public String getAchievementType() {
    return achievementType;
  }

  /**
   * The type of the achievement. Possible values are:   - "STANDARD" - Achievement is either locked
   * or unlocked.  - "INCREMENTAL" - Achievement is incremental.
   * The value set may be {@code null}.
   */
  public AchievementDefinition setAchievementType(String achievementType) {
    this.achievementType = achievementType;
    return this;
  }

  /**
   * The description of the achievement.
   * The value returned may be {@code null}.
   */
  public String getDescription() {
    return description;
  }

  /**
   * The description of the achievement.
   * The value set may be {@code null}.
   */
  public AchievementDefinition setDescription(String description) {
    this.description = description;
    return this;
  }

  /**
   * The total steps for an incremental achievement as a string.
   * The value returned may be {@code null}.
   */
  public String getFormattedTotalSteps() {
    return formattedTotalSteps;
  }

  /**
   * The total steps for an incremental achievement as a string.
   * The value set may be {@code null}.
   */
  public AchievementDefinition setFormattedTotalSteps(String formattedTotalSteps) {
    this.formattedTotalSteps = formattedTotalSteps;
    return this;
  }

  /**
   * The ID of the achievement.
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * The ID of the achievement.
   * The value set may be {@code null}.
   */
  public AchievementDefinition setId(String id) {
    this.id = id;
    return this;
  }

  /**
   * The initial state of the achievement. Possible values are:   - "HIDDEN" - Achievement is
   * hidden.  - "REVEALED" - Achievement is revealed.  - "UNLOCKED" - Achievement is unlocked.
   * The value returned may be {@code null}.
   */
  public String getInitialState() {
    return initialState;
  }

  /**
   * The initial state of the achievement. Possible values are:   - "HIDDEN" - Achievement is
   * hidden.  - "REVEALED" - Achievement is revealed.  - "UNLOCKED" - Achievement is unlocked.
   * The value set may be {@code null}.
   */
  public AchievementDefinition setInitialState(String initialState) {
    this.initialState = initialState;
    return this;
  }

  /**
   * Indicates whether the revealed icon image being returned is a default image, or is provided by
   * the game.
   * The value returned may be {@code null}.
   */
  public Boolean getIsRevealedIconUrlDefault() {
    return isRevealedIconUrlDefault;
  }

  /**
   * Indicates whether the revealed icon image being returned is a default image, or is provided by
   * the game.
   * The value set may be {@code null}.
   */
  public AchievementDefinition setIsRevealedIconUrlDefault(Boolean isRevealedIconUrlDefault) {
    this.isRevealedIconUrlDefault = isRevealedIconUrlDefault;
    return this;
  }

  /**
   * Indicates whether the unlocked icon image being returned is a default image, or is game-
   * provided.
   * The value returned may be {@code null}.
   */
  public Boolean getIsUnlockedIconUrlDefault() {
    return isUnlockedIconUrlDefault;
  }

  /**
   * Indicates whether the unlocked icon image being returned is a default image, or is game-
   * provided.
   * The value set may be {@code null}.
   */
  public AchievementDefinition setIsUnlockedIconUrlDefault(Boolean isUnlockedIconUrlDefault) {
    this.isUnlockedIconUrlDefault = isUnlockedIconUrlDefault;
    return this;
  }

  /**
   * Uniquely identifies the type of this resource. Value is always the fixed string
   * games#achievementDefinition.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * Uniquely identifies the type of this resource. Value is always the fixed string
   * games#achievementDefinition.
   * The value set may be {@code null}.
   */
  public AchievementDefinition setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The name of the achievement.
   * The value returned may be {@code null}.
   */
  public String getName() {
    return name;
  }

  /**
   * The name of the achievement.
   * The value set may be {@code null}.
   */
  public AchievementDefinition setName(String name) {
    this.name = name;
    return this;
  }

  /**
   * The image URL for the revealed achievement icon.
   * The value returned may be {@code null}.
   */
  public String getRevealedIconUrl() {
    return revealedIconUrl;
  }

  /**
   * The image URL for the revealed achievement icon.
   * The value set may be {@code null}.
   */
  public AchievementDefinition setRevealedIconUrl(String revealedIconUrl) {
    this.revealedIconUrl = revealedIconUrl;
    return this;
  }

  /**
   * The total steps for an incremental achievement.
   * The value returned may be {@code null}.
   */
  public Integer getTotalSteps() {
    return totalSteps;
  }

  /**
   * The total steps for an incremental achievement.
   * The value set may be {@code null}.
   */
  public AchievementDefinition setTotalSteps(Integer totalSteps) {
    this.totalSteps = totalSteps;
    return this;
  }

  /**
   * The image URL for the unlocked achievement icon.
   * The value returned may be {@code null}.
   */
  public String getUnlockedIconUrl() {
    return unlockedIconUrl;
  }

  /**
   * The image URL for the unlocked achievement icon.
   * The value set may be {@code null}.
   */
  public AchievementDefinition setUnlockedIconUrl(String unlockedIconUrl) {
    this.unlockedIconUrl = unlockedIconUrl;
    return this;
  }

}
