/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.games.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.json.JsonString;

/**
 * This is a JSON template for the Leaderboard Entry resource.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Google Play Game Services API. For a detailed
 * explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class LeaderboardEntry extends GenericJson {

  /**
   * The localized string for the numerical value of this score.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String formattedScore;

  /**
   * The localized string for the rank of this score for this leaderboard.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String formattedScoreRank;

  /**
   * Uniquely identifies the type of this resource. Value is always the fixed string
   * games#leaderboardEntry.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The player who holds this score.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Player player;

  /**
   * The rank of this score for this leaderboard.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long scoreRank;

  /**
   * The numerical value of this score.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long scoreValue;

  /**
   * The time span of this high score. Possible values are:   - "ALL_TIME" - The score is an all-
   * time high score.  - "WEEKLY" - The score is a weekly high score.  - "DAILY" - The score is a
   * daily high score.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String timeSpan;

  /**
   * The timestamp at which this score was recorded, in milliseconds since the epoch in UTC.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long writeTimestampMillis;

  /**
   * The localized string for the numerical value of this score.
   * The value returned may be {@code null}.
   */
  public String getFormattedScore() {
    return formattedScore;
  }

  /**
   * The localized string for the numerical value of this score.
   * The value set may be {@code null}.
   */
  public LeaderboardEntry setFormattedScore(String formattedScore) {
    this.formattedScore = formattedScore;
    return this;
  }

  /**
   * The localized string for the rank of this score for this leaderboard.
   * The value returned may be {@code null}.
   */
  public String getFormattedScoreRank() {
    return formattedScoreRank;
  }

  /**
   * The localized string for the rank of this score for this leaderboard.
   * The value set may be {@code null}.
   */
  public LeaderboardEntry setFormattedScoreRank(String formattedScoreRank) {
    this.formattedScoreRank = formattedScoreRank;
    return this;
  }

  /**
   * Uniquely identifies the type of this resource. Value is always the fixed string
   * games#leaderboardEntry.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * Uniquely identifies the type of this resource. Value is always the fixed string
   * games#leaderboardEntry.
   * The value set may be {@code null}.
   */
  public LeaderboardEntry setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The player who holds this score.
   * The value returned may be {@code null}.
   */
  public Player getPlayer() {
    return player;
  }

  /**
   * The player who holds this score.
   * The value set may be {@code null}.
   */
  public LeaderboardEntry setPlayer(Player player) {
    this.player = player;
    return this;
  }

  /**
   * The rank of this score for this leaderboard.
   * The value returned may be {@code null}.
   */
  public Long getScoreRank() {
    return scoreRank;
  }

  /**
   * The rank of this score for this leaderboard.
   * The value set may be {@code null}.
   */
  public LeaderboardEntry setScoreRank(Long scoreRank) {
    this.scoreRank = scoreRank;
    return this;
  }

  /**
   * The numerical value of this score.
   * The value returned may be {@code null}.
   */
  public Long getScoreValue() {
    return scoreValue;
  }

  /**
   * The numerical value of this score.
   * The value set may be {@code null}.
   */
  public LeaderboardEntry setScoreValue(Long scoreValue) {
    this.scoreValue = scoreValue;
    return this;
  }

  /**
   * The time span of this high score. Possible values are:   - "ALL_TIME" - The score is an all-
   * time high score.  - "WEEKLY" - The score is a weekly high score.  - "DAILY" - The score is a
   * daily high score.
   * The value returned may be {@code null}.
   */
  public String getTimeSpan() {
    return timeSpan;
  }

  /**
   * The time span of this high score. Possible values are:   - "ALL_TIME" - The score is an all-
   * time high score.  - "WEEKLY" - The score is a weekly high score.  - "DAILY" - The score is a
   * daily high score.
   * The value set may be {@code null}.
   */
  public LeaderboardEntry setTimeSpan(String timeSpan) {
    this.timeSpan = timeSpan;
    return this;
  }

  /**
   * The timestamp at which this score was recorded, in milliseconds since the epoch in UTC.
   * The value returned may be {@code null}.
   */
  public Long getWriteTimestampMillis() {
    return writeTimestampMillis;
  }

  /**
   * The timestamp at which this score was recorded, in milliseconds since the epoch in UTC.
   * The value set may be {@code null}.
   */
  public LeaderboardEntry setWriteTimestampMillis(Long writeTimestampMillis) {
    this.writeTimestampMillis = writeTimestampMillis;
    return this;
  }

}
