/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.games.model;

import com.google.api.client.json.GenericJson;

/**
 * This is a JSON template for a room resource object.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Google Play Game Services API. For a detailed
 * explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Room extends GenericJson {

  /**
   * The ID of the application being played.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String applicationId;

  /**
   * Criteria for auto-matching players into this room.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private RoomAutoMatchingCriteria autoMatchingCriteria;

  /**
   * Auto-matching status for this room. Not set if the room is not currently in the automatching
   * status.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private RoomAutoMatchStatus autoMatchingStatus;

  /**
   * Details about the room creation.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private RoomModification creationDetails;

  /**
   * This short description is generated by our servers and worded relative to the player requesting
   * the room. It is intended to be displayed when the room is shown in a list (that is, an
   * invitation to a room.)
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String description;

  /**
   * Uniquely identifies the type of this resource. Value is always the fixed string games#room.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * Details about the last update to the room.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private RoomModification lastUpdateDetails;

  /**
   * The participants involved in the room, along with their statuses. Includes participants who
   * have left or declined invitations.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<RoomParticipant> participants;

  static {
    // hack to force ProGuard to consider RoomParticipant used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(RoomParticipant.class);
  }

  /**
   * Globally unique ID for a room.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String roomId;

  /**
   * The version of the room status: an increasing counter, used by the client to ignore out-of-
   * order updates to room status.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Integer roomStatusVersion;

  /**
   * The status of the room. Possible values are:   - "ROOM_INVITING" - One or more players have
   * been invited and not responded.  - "ROOM_AUTO_MATCHING" - One or more slots need to be filled
   * by auto-matching.  - "ROOM_CONNECTING" - Players have joined and are connecting to each other
   * (either before or after auto-matching).  - "ROOM_ACTIVE" - All players have joined and
   * connected to each other.  - "ROOM_DELETED" - The room should no longer be shown on the client.
   * Returned in sync calls when a player joins a room (as a tombstone), or for rooms where all
   * joined participants have left.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String status;

  /**
   * The variant / mode of the application being played; can be any integer value, or left blank.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Integer variant;

  /**
   * The ID of the application being played.
   * The value returned may be {@code null}.
   */
  public String getApplicationId() {
    return applicationId;
  }

  /**
   * The ID of the application being played.
   * The value set may be {@code null}.
   */
  public Room setApplicationId(String applicationId) {
    this.applicationId = applicationId;
    return this;
  }

  /**
   * Criteria for auto-matching players into this room.
   * The value returned may be {@code null}.
   */
  public RoomAutoMatchingCriteria getAutoMatchingCriteria() {
    return autoMatchingCriteria;
  }

  /**
   * Criteria for auto-matching players into this room.
   * The value set may be {@code null}.
   */
  public Room setAutoMatchingCriteria(RoomAutoMatchingCriteria autoMatchingCriteria) {
    this.autoMatchingCriteria = autoMatchingCriteria;
    return this;
  }

  /**
   * Auto-matching status for this room. Not set if the room is not currently in the automatching
   * status.
   * The value returned may be {@code null}.
   */
  public RoomAutoMatchStatus getAutoMatchingStatus() {
    return autoMatchingStatus;
  }

  /**
   * Auto-matching status for this room. Not set if the room is not currently in the automatching
   * status.
   * The value set may be {@code null}.
   */
  public Room setAutoMatchingStatus(RoomAutoMatchStatus autoMatchingStatus) {
    this.autoMatchingStatus = autoMatchingStatus;
    return this;
  }

  /**
   * Details about the room creation.
   * The value returned may be {@code null}.
   */
  public RoomModification getCreationDetails() {
    return creationDetails;
  }

  /**
   * Details about the room creation.
   * The value set may be {@code null}.
   */
  public Room setCreationDetails(RoomModification creationDetails) {
    this.creationDetails = creationDetails;
    return this;
  }

  /**
   * This short description is generated by our servers and worded relative to the player requesting
   * the room. It is intended to be displayed when the room is shown in a list (that is, an
   * invitation to a room.)
   * The value returned may be {@code null}.
   */
  public String getDescription() {
    return description;
  }

  /**
   * This short description is generated by our servers and worded relative to the player requesting
   * the room. It is intended to be displayed when the room is shown in a list (that is, an
   * invitation to a room.)
   * The value set may be {@code null}.
   */
  public Room setDescription(String description) {
    this.description = description;
    return this;
  }

  /**
   * Uniquely identifies the type of this resource. Value is always the fixed string games#room.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * Uniquely identifies the type of this resource. Value is always the fixed string games#room.
   * The value set may be {@code null}.
   */
  public Room setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * Details about the last update to the room.
   * The value returned may be {@code null}.
   */
  public RoomModification getLastUpdateDetails() {
    return lastUpdateDetails;
  }

  /**
   * Details about the last update to the room.
   * The value set may be {@code null}.
   */
  public Room setLastUpdateDetails(RoomModification lastUpdateDetails) {
    this.lastUpdateDetails = lastUpdateDetails;
    return this;
  }

  /**
   * The participants involved in the room, along with their statuses. Includes participants who
   * have left or declined invitations.
   * The value returned may be {@code null}.
   */
  public java.util.List<RoomParticipant> getParticipants() {
    return participants;
  }

  /**
   * The participants involved in the room, along with their statuses. Includes participants who
   * have left or declined invitations.
   * The value set may be {@code null}.
   */
  public Room setParticipants(java.util.List<RoomParticipant> participants) {
    this.participants = participants;
    return this;
  }

  /**
   * Globally unique ID for a room.
   * The value returned may be {@code null}.
   */
  public String getRoomId() {
    return roomId;
  }

  /**
   * Globally unique ID for a room.
   * The value set may be {@code null}.
   */
  public Room setRoomId(String roomId) {
    this.roomId = roomId;
    return this;
  }

  /**
   * The version of the room status: an increasing counter, used by the client to ignore out-of-
   * order updates to room status.
   * The value returned may be {@code null}.
   */
  public Integer getRoomStatusVersion() {
    return roomStatusVersion;
  }

  /**
   * The version of the room status: an increasing counter, used by the client to ignore out-of-
   * order updates to room status.
   * The value set may be {@code null}.
   */
  public Room setRoomStatusVersion(Integer roomStatusVersion) {
    this.roomStatusVersion = roomStatusVersion;
    return this;
  }

  /**
   * The status of the room. Possible values are:   - "ROOM_INVITING" - One or more players have
   * been invited and not responded.  - "ROOM_AUTO_MATCHING" - One or more slots need to be filled
   * by auto-matching.  - "ROOM_CONNECTING" - Players have joined and are connecting to each other
   * (either before or after auto-matching).  - "ROOM_ACTIVE" - All players have joined and
   * connected to each other.  - "ROOM_DELETED" - The room should no longer be shown on the client.
   * Returned in sync calls when a player joins a room (as a tombstone), or for rooms where all
   * joined participants have left.
   * The value returned may be {@code null}.
   */
  public String getStatus() {
    return status;
  }

  /**
   * The status of the room. Possible values are:   - "ROOM_INVITING" - One or more players have
   * been invited and not responded.  - "ROOM_AUTO_MATCHING" - One or more slots need to be filled
   * by auto-matching.  - "ROOM_CONNECTING" - Players have joined and are connecting to each other
   * (either before or after auto-matching).  - "ROOM_ACTIVE" - All players have joined and
   * connected to each other.  - "ROOM_DELETED" - The room should no longer be shown on the client.
   * Returned in sync calls when a player joins a room (as a tombstone), or for rooms where all
   * joined participants have left.
   * The value set may be {@code null}.
   */
  public Room setStatus(String status) {
    this.status = status;
    return this;
  }

  /**
   * The variant / mode of the application being played; can be any integer value, or left blank.
   * The value returned may be {@code null}.
   */
  public Integer getVariant() {
    return variant;
  }

  /**
   * The variant / mode of the application being played; can be any integer value, or left blank.
   * The value set may be {@code null}.
   */
  public Room setVariant(Integer variant) {
    this.variant = variant;
    return this;
  }

}
